==> haskell-path-io-1.4.2-13-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.4.2
id: path-io-1.4.2-G3VsLJqEqpECdXjtMo9hKf
key: path-io-1.4.2-G3VsLJqEqpECdXjtMo9hKf
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
abi: 72817fb2ee5c4c2720215a0fb6247b85
exposed: True
exposed-modules:
    Path.IO
import-dirs: /usr/lib/ghc-8.6.5/site-local/path-io-1.4.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/path-io-1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/path-io-1.4.2
hs-libraries: HSpath-io-1.4.2-G3VsLJqEqpECdXjtMo9hKf
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH filepath-1.4.2.1
    path-0.6.1-H3QMI7gUHKeD6elmYzti9J
    temporary-1.3-2R9bhTuduqsDRv55IV8XfU time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-path-io-1.4.2-14-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-path-io.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: path-io
version: 1.4.2
id: path-io-1.4.2-4sVmIjryT8YKsrJIk60XnK
key: path-io-1.4.2-4sVmIjryT8YKsrJIk60XnK
license: BSD-3-Clause
maintainer: Mark Karpov <markkarpov92@gmail.com>
author: Mark Karpov <markkarpov92@gmail.com>
homepage: https://github.com/mrkkrp/path-io
synopsis: Interface to ‘directory’ package for users of ‘path’
description:
    Interface to ‘directory’ package for users of ‘path’.
category: System, Filesystem
abi: bc750f92635bda02a35403dced872f3e
exposed: True
exposed-modules:
    Path.IO
import-dirs: /usr/lib/ghc-8.6.5/site-local/path-io-1.4.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/path-io-1.4.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/path-io-1.4.2
hs-libraries: HSpath-io-1.4.2-4sVmIjryT8YKsrJIk60XnK
depends:
    base-4.12.0.0 containers-0.6.0.1 directory-1.3.3.0
    dlist-0.8.0.6-CQRMCGRgL5B3ZxhntX4iOr
    exceptions-0.10.1-7EeRXpdm0c5D9yRsXefkxH filepath-1.4.2.1
    path-0.6.1-F0neH8TCoNp3ER00THkoPe
    temporary-1.3-2R9bhTuduqsDRv55IV8XfU time-1.8.0.2
    transformers-0.5.6.2 unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
haddock-interfaces: /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html: /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
